#!/bin/sh
#################################################################################
# The purpose of this script is to be a wrapper for support data manipulations on the
#   database done up to now by psql.
# The script supports all original psql flags and records the executed SQL and its
#   results in /var/log/ovirt-engine/engine-psql.log
# The scripts supports both original -c <sql command> and -f <file> as also
# their equivalent --command <sql command> and --file <file> and
# --command=<sql command> and --file=<file>
#################################################################################

# Load vars file:
. /usr/share/ovirt-engine/bin/engine-prolog.sh

LOGDIR="${ENGINE_LOG}/db-manual"
LOGFILE="${LOGDIR}/$(date +"%Y%m%d%H%M%S")-engine-psql.log"
FILE=""

usage() {
	psql --help | sed "s@psql@$(basename "$0")@g"
	exit 0
}

log() {
	local m="$1"
	echo "${m}" >> "${LOGFILE}"
}

# we have to log the file content
# supporting here all possible formats : -f <file> --file <file> and --file=<file>
parseArgs() {
	while [ -n "$1" ]; do
		local x="$1"
		local v="${x#*=}"
		shift
		case "${x}" in
			--file=*)
				FILE="${v}"
				;;
			-f|--file)
				FILE="$1"
				shift
				;;
			-h|-help|--help)
				usage
				;;
		esac
	done
}

# do this in function so we do not lose $@
parseArgs "$@"

if [ ! -d "${LOGDIR}" ]; then
  mkdir "${LOGDIR}"
fi

[ -r "${ENGINE_DEFAULTS}" ] || die "Can't load defaults file \"${ENGINE_DEFAULTS}\"."
[ -d "${LOGDIR}" ] || die "Can not find log directory ${LOGDIR}"
[ -w "${LOGDIR}" ] || die "Insufficient permissions on ${LOGDIR}"

USERNAME="${ENGINE_DB_USER}"
HOST="${ENGINE_DB_HOST}"
PORT="${ENGINE_DB_PORT}"
 
for f in \
	"${ENGINE_DEFAULTS}" \
	"${ENGINE_VARS}" \
	$([ -d "${ENGINE_VARS}.d" ] && find "${ENGINE_VARS}.d" -name '*.conf' | sort) \
	; do
	[ -r "${f}" ] && . "${f}"
done

log "$(date): executing command : ${0} $*"

# Echo file content to the log file
if [ -n "${FILE}" ]; then
	[ -r "${FILE}" ] || die "${FILE} is unreadable."
	log "file content is:"
	cat "${FILE}" >> "${LOGFILE}"
fi

log "output:"
export PGPASSWORD=${ENGINE_DB_PASSWORD}
psql -U "${USERNAME}" -h "${HOST}" -p "${port}" engine "$@" | tee "${LOGFILE}" 2>&1
ret=$?
log "result: ${ret}"

# Compress the file
gzip "${LOGFILE}"
exit $ret
